============
Installation
============

Install the package with pip:

.. code-block:: sh

    $ pip install cool-django-auth-ldap

It requires `python-ldap`_ >= 3.0. You'll need the `OpenLDAP`_ libraries and
headers available on your system.
